==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","ͤس");
define("_OK","ŧ!");
define("_COMMENT","ͤԴ");
define("_CONFIGURE","ûѺ¹ҵԴ");
define("_LOGINCREATE","ѤҪԡ");
define("_THRESHOLD","ṹ");
define("_NOCOMMENTS","դ");
define("_NESTED","͡");
define("_FLAT","ʴǵç");
define("_THREAD","ʴдѺ");
define("_OLDEST","ҡ͹");
define("_NEWEST","͹");
define("_HIGHEST","§ṹ٧͹");
define("_COMMENTSWARNING","Դ繷ʴ繢ͧ繢ͧŧС. ҧ䫵 ѺԴͺҹ.");
define("_SCORE","ṹ:");
define("_USERINFO","ż");
define("_READREST","ҹ繵...");
define("_REPLY","ͺѺ");
define("_REPLYMAIN","Ԩó");
define("_NOSUBJECT","ѧժͧ");
define("_NOANONCOMMENTS","ŧ¹ Էʴ , ô <a href=\"modules.php?name=Your_Account\">ŧ¹</a>");
define("_PARENT","Ǣ");
define("_ROOT","Root");
define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML ö:");
define("_POSTANON","ѹ֡ ʧ͡");
define("_EXTRANS","Extrans (¹ html tags ѡø)");
define("_HTMLFORMATED","ѹ֡ HTML");
define("_PLAINTEXT","Ż");
define("_ONN","on...");
define("_SUBJECT","ͧ");
define("_SURVEYCOM","ǨԴ");
define("_SURVEYCOMPRE","ʴ Ǩ");
define("_NOTRIGHT","պҧ觺ҧҧԴá 㹡觤");
define("_DIRECTCOM","繵ԸաǨ...");
define("_SENDAMSG","觢͡");
define("_PASTSURVEYS","繷ҹ");
define("_LVOTES","ʴ");
define("_TOTALVOTES","繷:");
define("_VOTING","ʴ");
define("_OTHERPOLLS","ͧ");
define("_CURRENTSURVEY","ͧѧǨ");
define("_CURRENTPOLLRESULTS","Ǩй");
define("_PREVIEW","ͧʴźҾ");
define("_REFRESH","ʴ");
define("_SURVEYS","Surveys");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","ͤس");
define("_OK","ŧ!");
define("_COMMENT","ͤԴ");
define("_CONFIGURE","ûѺ¹ҵԴ");
define("_LOGINCREATE","ѤҪԡ");
define("_THRESHOLD","ṹ");
define("_NOCOMMENTS","դ");
define("_NESTED","͡");
define("_FLAT","ʴǵç");
define("_THREAD","ʴдѺ");
define("_OLDEST","ҡ͹");
define("_NEWEST","͹");
define("_HIGHEST","§ṹ٧͹");
define("_COMMENTSWARNING","Դ繷ʴ繢ͧ繢ͧŧС. ҧ䫵 ѺԴͺҹ.");
define("_SCORE","ṹ:");
define("_USERINFO","ż");
define("_READREST","ҹ繵...");
define("_REPLY","ͺѺ");
define("_REPLYMAIN","Ԩó");
define("_NOSUBJECT","ѧժͧ");
define("_NOANONCOMMENTS","ŧ¹ Էʴ , ô <a href=\"modules.php?name=Your_Account\">ŧ¹</a>");
define("_PARENT","Ǣ");
define("_ROOT","Root");
define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML ö:");
define("_POSTANON","ѹ֡ ʧ͡");
define("_EXTRANS","Extrans (¹ html tags ѡø)");
define("_HTMLFORMATED","ѹ֡ HTML");
define("_PLAINTEXT","Ż");
define("_ONN","on...");
define("_SUBJECT","ͧ");
define("_SURVEYCOM","ǨԴ");
define("_SURVEYCOMPRE","ʴ Ǩ");
define("_NOTRIGHT","պҧ觺ҧҧԴá 㹡觤");
define("_DIRECTCOM","繵ԸաǨ...");
define("_SENDAMSG","觢͡");
define("_PASTSURVEYS","繷ҹ");
define("_LVOTES","ʴ");
define("_TOTALVOTES","繷:");
define("_VOTING","ʴ");
define("_OTHERPOLLS","ͧ");
define("_CURRENTSURVEY","ͧѧǨ");
define("_CURRENTPOLLRESULTS","Ǩй");
define("_PREVIEW","ͧʴźҾ");
define("_REFRESH","ʴ");
define("_SURVEYS","Surveys");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
